@@ -1,4 +1,4 @@
-## Copyright (C)       2010 - 2017  Dirk Eddelbuettel, Romain Francois and Douglas Bates
+## Copyright (C) 2010 - 2024  Dirk Eddelbuettel, Romain Francois and Douglas Bates
 ##
 ## This file is part of RcppArmadillo.
 ##
@@ -18,15 +18,10 @@
 inlineCxxPlugin <- function(...) {
     ismacos <- Sys.info()[["sysname"]] == "Darwin"
     openmpflag <- if (ismacos) "" else "$(SHLIB_OPENMP_CFLAGS)"
-    plugin <-
-        Rcpp::Rcpp.plugin.maker(
-                  include.before = "#include <RcppArmadillo.h>",
-                  libs           = paste(openmpflag, "$(LAPACK_LIBS) $(BLAS_LIBS) $(FLIBS)"),
-                  package        = "RcppArmadillo"
-              )
+    plugin <-  Rcpp::Rcpp.plugin.maker(include.before = "#include <RcppArmadillo.h>",
+                                       libs           = paste(openmpflag, "$(LAPACK_LIBS) $(BLAS_LIBS) $(FLIBS)"),
+                                       package        = "RcppArmadillo")
     settings <- plugin()
     settings$env$PKG_CPPFLAGS <- paste("-I../inst/include", openmpflag)
-    if (!ismacos) settings$env$USE_CXX11 <- "yes"
     settings
 }
-
