@@ -28,7 +28,7 @@ template<typename eT>
 inline
 gmm_diag<eT>::~gmm_diag()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   arma_type_check(( (is_same_type<eT,float>::value == false) && (is_same_type<eT,double>::value == false) ));
   }
@@ -39,7 +39,7 @@ template<typename eT>
 inline
 gmm_diag<eT>::gmm_diag()
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   }
 
 
@@ -48,7 +48,7 @@ template<typename eT>
 inline
 gmm_diag<eT>::gmm_diag(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(x);
   }
@@ -60,7 +60,7 @@ inline
 gmm_diag<eT>&
 gmm_diag<eT>::operator=(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(x);
   
@@ -73,7 +73,7 @@ template<typename eT>
 inline
 gmm_diag<eT>::gmm_diag(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(x);
   }
@@ -85,7 +85,7 @@ inline
 gmm_diag<eT>&
 gmm_diag<eT>::operator=(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(x);
   
@@ -98,7 +98,7 @@ template<typename eT>
 inline
 gmm_diag<eT>::gmm_diag(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint_this(this);
+  arma_debug_sigprint_this(this);
   
   init(in_n_dims, in_n_gaus);
   }
@@ -110,7 +110,7 @@ inline
 void
 gmm_diag<eT>::reset()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(0, 0);
   }
@@ -122,7 +122,7 @@ inline
 void
 gmm_diag<eT>::reset(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   init(in_n_dims, in_n_gaus);
   }
@@ -135,7 +135,7 @@ inline
 void
 gmm_diag<eT>::set_params(const Base<eT,T1>& in_means_expr, const Base<eT,T2>& in_dcovs_expr, const Base<eT,T3>& in_hefts_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp1(in_means_expr.get_ref());
   const unwrap<T2> tmp2(in_dcovs_expr.get_ref());
@@ -145,22 +145,22 @@ gmm_diag<eT>::set_params(const Base<eT,T1>& in_means_expr, const Base<eT,T2>& in
   const Mat<eT>& in_dcovs = tmp2.M;
   const Mat<eT>& in_hefts = tmp3.M;
   
-  arma_debug_check
+  arma_conform_check
     (
     (arma::size(in_means) != arma::size(in_dcovs)) || (in_hefts.n_cols != in_means.n_cols) || (in_hefts.n_rows != 1),
     "gmm_diag::set_params(): given parameters have inconsistent and/or wrong sizes"
     );
   
-  arma_debug_check( (in_means.is_finite() == false), "gmm_diag::set_params(): given means have non-finite values" );
-  arma_debug_check( (in_dcovs.is_finite() == false), "gmm_diag::set_params(): given dcovs have non-finite values" );
-  arma_debug_check( (in_hefts.is_finite() == false), "gmm_diag::set_params(): given hefts have non-finite values" );
+  arma_conform_check( (in_means.internal_has_nonfinite()), "gmm_diag::set_params(): given means have non-finite values" );
+  arma_conform_check( (in_dcovs.internal_has_nonfinite()), "gmm_diag::set_params(): given dcovs have non-finite values" );
+  arma_conform_check( (in_hefts.internal_has_nonfinite()), "gmm_diag::set_params(): given hefts have non-finite values" );
   
-  arma_debug_check( (any(vectorise(in_dcovs) <= eT(0))), "gmm_diag::set_params(): given dcovs have negative or zero values" );
-  arma_debug_check( (any(vectorise(in_hefts) <  eT(0))), "gmm_diag::set_params(): given hefts have negative values"         );
+  arma_conform_check( (any(vectorise(in_dcovs) <= eT(0))), "gmm_diag::set_params(): given dcovs have negative or zero values" );
+  arma_conform_check( (any(vectorise(in_hefts) <  eT(0))), "gmm_diag::set_params(): given hefts have negative values"         );
   
   const eT s = accu(in_hefts);
   
-  arma_debug_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_diag::set_params(): sum of given hefts is not 1" );
+  arma_conform_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_diag::set_params(): sum of given hefts is not 1" );
   
   access::rw(means) = in_means;
   access::rw(dcovs) = in_dcovs;
@@ -177,14 +177,14 @@ inline
 void
 gmm_diag<eT>::set_means(const Base<eT,T1>& in_means_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp(in_means_expr.get_ref());
   
   const Mat<eT>& in_means = tmp.M;
   
-  arma_debug_check( (arma::size(in_means) != arma::size(means)), "gmm_diag::set_means(): given means have incompatible size" );
-  arma_debug_check( (in_means.is_finite() == false),             "gmm_diag::set_means(): given means have non-finite values" );
+  arma_conform_check( (arma::size(in_means) != arma::size(means)), "gmm_diag::set_means(): given means have incompatible size" );
+  arma_conform_check( (in_means.internal_has_nonfinite()),         "gmm_diag::set_means(): given means have non-finite values" );
   
   access::rw(means) = in_means;
   }
@@ -197,15 +197,15 @@ inline
 void
 gmm_diag<eT>::set_dcovs(const Base<eT,T1>& in_dcovs_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp(in_dcovs_expr.get_ref());
   
   const Mat<eT>& in_dcovs = tmp.M;
   
-  arma_debug_check( (arma::size(in_dcovs) != arma::size(dcovs)), "gmm_diag::set_dcovs(): given dcovs have incompatible size"       );
-  arma_debug_check( (in_dcovs.is_finite() == false),             "gmm_diag::set_dcovs(): given dcovs have non-finite values"       );
-  arma_debug_check( (any(vectorise(in_dcovs) <= eT(0))),         "gmm_diag::set_dcovs(): given dcovs have negative or zero values" );
+  arma_conform_check( (arma::size(in_dcovs) != arma::size(dcovs)), "gmm_diag::set_dcovs(): given dcovs have incompatible size"       );
+  arma_conform_check( (in_dcovs.internal_has_nonfinite()),         "gmm_diag::set_dcovs(): given dcovs have non-finite values"       );
+  arma_conform_check( (any(vectorise(in_dcovs) <= eT(0))),         "gmm_diag::set_dcovs(): given dcovs have negative or zero values" );
   
   access::rw(dcovs) = in_dcovs;
   
@@ -220,19 +220,19 @@ inline
 void
 gmm_diag<eT>::set_hefts(const Base<eT,T1>& in_hefts_expr)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1> tmp(in_hefts_expr.get_ref());
   
   const Mat<eT>& in_hefts = tmp.M;
   
-  arma_debug_check( (arma::size(in_hefts) != arma::size(hefts)), "gmm_diag::set_hefts(): given hefts have incompatible size" );
-  arma_debug_check( (in_hefts.is_finite() == false),             "gmm_diag::set_hefts(): given hefts have non-finite values" );
-  arma_debug_check( (any(vectorise(in_hefts) <  eT(0))),         "gmm_diag::set_hefts(): given hefts have negative values"   );
+  arma_conform_check( (arma::size(in_hefts) != arma::size(hefts)), "gmm_diag::set_hefts(): given hefts have incompatible size" );
+  arma_conform_check( (in_hefts.internal_has_nonfinite()),         "gmm_diag::set_hefts(): given hefts have non-finite values" );
+  arma_conform_check( (any(vectorise(in_hefts) <  eT(0))),         "gmm_diag::set_hefts(): given hefts have negative values"   );
   
   const eT s = accu(in_hefts);
   
-  arma_debug_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_diag::set_hefts(): sum of given hefts is not 1" );
+  arma_conform_check( ((s < (eT(1) - eT(0.001))) || (s > (eT(1) + eT(0.001)))), "gmm_diag::set_hefts(): sum of given hefts is not 1" );
   
   // make sure all hefts are positive and non-zero
   
@@ -276,7 +276,7 @@ inline
 bool
 gmm_diag<eT>::load(const std::string name)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Cube<eT> Q;
   
@@ -285,7 +285,7 @@ gmm_diag<eT>::load(const std::string name)
   if( (status == false) || (Q.n_slices != 2) )
     {
     reset();
-    arma_debug_warn_level(3, "gmm_diag::load(): problem with loading or incompatible format");
+    arma_warn(3, "gmm_diag::load(): problem with loading or incompatible format");
     return false;
     }
   
@@ -311,7 +311,7 @@ inline
 bool
 gmm_diag<eT>::save(const std::string name) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   Cube<eT> Q(means.n_rows + 1, means.n_cols, 2, arma_nozeros_indicator());
   
@@ -336,7 +336,7 @@ inline
 Col<eT>
 gmm_diag<eT>::generate() const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -371,7 +371,7 @@ inline
 Mat<eT>
 gmm_diag<eT>::generate(const uword N_vec) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -416,13 +416,13 @@ inline
 eT
 gmm_diag<eT>::log_p(const T1& expr, const gmm_empty_arg& junk1, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
   const quasi_unwrap<T1> tmp(expr);
   
-  arma_debug_check( (tmp.M.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
+  arma_conform_check( (tmp.M.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
   
   return internal_scalar_log_p( tmp.M.memptr() );
   }
@@ -435,14 +435,14 @@ inline
 eT
 gmm_diag<eT>::log_p(const T1& expr, const uword gaus_id, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
   
   const quasi_unwrap<T1> tmp(expr);
   
-  arma_debug_check( (tmp.M.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
+  arma_conform_check( (tmp.M.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
   
-  arma_debug_check( (gaus_id >= means.n_cols), "gmm_diag::log_p(): specified gaussian is out of range" );
+  arma_conform_check( (gaus_id >= means.n_cols), "gmm_diag::log_p(): specified gaussian is out of range" );
   
   return internal_scalar_log_p( tmp.M.memptr(), gaus_id );
   }
@@ -455,7 +455,7 @@ inline
 Row<eT>
 gmm_diag<eT>::log_p(const T1& expr, const gmm_empty_arg& junk1, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
@@ -474,7 +474,7 @@ inline
 Row<eT>
 gmm_diag<eT>::log_p(const T1& expr, const uword gaus_id, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk2) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk2);
   
   const quasi_unwrap<T1> tmp(expr);
@@ -492,7 +492,7 @@ inline
 eT
 gmm_diag<eT>::sum_log_p(const Base<eT,T1>& expr) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -509,7 +509,7 @@ inline
 eT
 gmm_diag<eT>::sum_log_p(const Base<eT,T1>& expr, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -526,7 +526,7 @@ inline
 eT
 gmm_diag<eT>::avg_log_p(const Base<eT,T1>& expr) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -543,7 +543,7 @@ inline
 eT
 gmm_diag<eT>::avg_log_p(const Base<eT,T1>& expr, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const quasi_unwrap<T1> tmp(expr.get_ref());
   
@@ -560,7 +560,7 @@ inline
 uword
 gmm_diag<eT>::assign(const T1& expr, const gmm_dist_mode& dist, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == true))>::result* junk) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   const quasi_unwrap<T1> tmp(expr);
@@ -578,7 +578,7 @@ inline
 urowvec
 gmm_diag<eT>::assign(const T1& expr, const gmm_dist_mode& dist, typename enable_if<((is_arma_type<T1>::value) && (resolves_to_colvector<T1>::value == false))>::result* junk) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   arma_ignore(junk);
   
   urowvec out;
@@ -600,14 +600,14 @@ inline
 urowvec
 gmm_diag<eT>::raw_hist(const Base<eT,T1>& expr, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1>   tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::raw_hist(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::raw_hist(): incompatible dimensions" );
   
-  arma_debug_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_diag::raw_hist(): unsupported distance mode" );
+  arma_conform_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_diag::raw_hist(): unsupported distance mode" );
   
   urowvec hist;
   
@@ -624,14 +624,14 @@ inline
 Row<eT>
 gmm_diag<eT>::norm_hist(const Base<eT,T1>& expr, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const unwrap<T1>   tmp(expr.get_ref());
   const Mat<eT>& X = tmp.M;
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::norm_hist(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::norm_hist(): incompatible dimensions" );
   
-  arma_debug_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_diag::norm_hist(): unsupported distance mode" );
+  arma_conform_check( ((dist_mode != eucl_dist) && (dist_mode != prob_dist)), "gmm_diag::norm_hist(): unsupported distance mode" );
   
   urowvec hist;
   
@@ -672,7 +672,7 @@ gmm_diag<eT>::learn
   const bool           print_mode
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool dist_mode_ok = (dist_mode == eucl_dist) || (dist_mode == maha_dist);
   
@@ -683,15 +683,15 @@ gmm_diag<eT>::learn
     || (seed_mode == random_subset)
     || (seed_mode == random_spread);
   
-  arma_debug_check( (dist_mode_ok == false), "gmm_diag::learn(): dist_mode must be eucl_dist or maha_dist" );
-  arma_debug_check( (seed_mode_ok == false), "gmm_diag::learn(): unknown seed_mode"                        );
-  arma_debug_check( (var_floor < eT(0)    ), "gmm_diag::learn(): variance floor is negative"               );
+  arma_conform_check( (dist_mode_ok == false), "gmm_diag::learn(): dist_mode must be eucl_dist or maha_dist" );
+  arma_conform_check( (seed_mode_ok == false), "gmm_diag::learn(): unknown seed_mode"                        );
+  arma_conform_check( (var_floor < eT(0)    ), "gmm_diag::learn(): variance floor is negative"               );
   
   const unwrap<T1>   tmp_X(data.get_ref());
   const Mat<eT>& X = tmp_X.M;
   
-  if(X.is_empty()          )  { arma_debug_warn_level(3, "gmm_diag::learn(): given matrix is empty"             ); return false; }
-  if(X.is_finite() == false)  { arma_debug_warn_level(3, "gmm_diag::learn(): given matrix has non-finite values"); return false; }
+  if(X.is_empty()              )  { arma_warn(3, "gmm_diag::learn(): given matrix is empty"             ); return false; }
+  if(X.internal_has_nonfinite())  { arma_warn(3, "gmm_diag::learn(): given matrix has non-finite values"); return false; }
   
   if(N_gaus == 0)  { reset(); return true; }
   
@@ -720,14 +720,14 @@ gmm_diag<eT>::learn
   
   if(seed_mode == keep_existing)
     {
-    if(means.is_empty()        )  { arma_debug_warn_level(3, "gmm_diag::learn(): no existing means"      ); return false; }
-    if(X.n_rows != means.n_rows)  { arma_debug_warn_level(3, "gmm_diag::learn(): dimensionality mismatch"); return false; }
+    if(means.is_empty()        )  { arma_warn(3, "gmm_diag::learn(): no existing means"      ); return false; }
+    if(X.n_rows != means.n_rows)  { arma_warn(3, "gmm_diag::learn(): dimensionality mismatch"); return false; }
     
     // TODO: also check for number of vectors?
     }
   else
     {
-    if(X.n_cols < N_gaus)  { arma_debug_warn_level(3, "gmm_diag::learn(): number of vectors is less than number of gaussians"); return false; }
+    if(X.n_cols < N_gaus)  { arma_warn(3, "gmm_diag::learn(): number of vectors is less than number of gaussians"); return false; }
     
     reset(X.n_rows, N_gaus);
     
@@ -751,7 +751,7 @@ gmm_diag<eT>::learn
     
     stream_state.restore(get_cout_stream());
     
-    if(status == false)  { arma_debug_warn_level(3, "gmm_diag::learn(): k-means algorithm failed; not enough data, or too many gaussians requested"); init(orig); return false; }
+    if(status == false)  { arma_warn(3, "gmm_diag::learn(): k-means algorithm failed; not enough data, or too many gaussians requested"); init(orig); return false; }
     }
   
   
@@ -778,7 +778,7 @@ gmm_diag<eT>::learn
     
     stream_state.restore(get_cout_stream());
     
-    if(status == false)  { arma_debug_warn_level(3, "gmm_diag::learn(): EM algorithm failed"); init(orig); return false; }
+    if(status == false)  { arma_warn(3, "gmm_diag::learn(): EM algorithm failed"); init(orig); return false; }
     }
   
   mah_aux.reset();
@@ -804,7 +804,7 @@ gmm_diag<eT>::kmeans_wrapper
   const bool           print_mode
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const bool seed_mode_ok = \
        (seed_mode == keep_existing)
@@ -813,13 +813,13 @@ gmm_diag<eT>::kmeans_wrapper
     || (seed_mode == random_subset)
     || (seed_mode == random_spread);
   
-  arma_debug_check( (seed_mode_ok == false), "kmeans(): unknown seed_mode" );
+  arma_conform_check( (seed_mode_ok == false), "kmeans(): unknown seed_mode" );
   
   const unwrap<T1>   tmp_X(data.get_ref());
   const Mat<eT>& X = tmp_X.M;
   
-  if(X.is_empty()          )  { arma_debug_warn_level(3, "kmeans(): given matrix is empty"             ); return false; }
-  if(X.is_finite() == false)  { arma_debug_warn_level(3, "kmeans(): given matrix has non-finite values"); return false; }
+  if(X.is_empty()              )  { arma_warn(3, "kmeans(): given matrix is empty"             ); return false; }
+  if(X.internal_has_nonfinite())  { arma_warn(3, "kmeans(): given matrix has non-finite values"); return false; }
   
   if(N_gaus == 0)  { reset(); return true; }
   
@@ -830,14 +830,14 @@ gmm_diag<eT>::kmeans_wrapper
     {
     access::rw(means) = user_means;
     
-    if(means.is_empty()        )  { arma_debug_warn_level(3, "kmeans(): no existing means"      ); return false; }
-    if(X.n_rows != means.n_rows)  { arma_debug_warn_level(3, "kmeans(): dimensionality mismatch"); return false; }
+    if(means.is_empty()        )  { arma_warn(3, "kmeans(): no existing means"      ); return false; }
+    if(X.n_rows != means.n_rows)  { arma_warn(3, "kmeans(): dimensionality mismatch"); return false; }
     
     // TODO: also check for number of vectors?
     }
   else
     {
-    if(X.n_cols < N_gaus)  { arma_debug_warn_level(3, "kmeans(): number of vectors is less than number of means"); return false; }
+    if(X.n_cols < N_gaus)  { arma_warn(3, "kmeans(): number of vectors is less than number of means"); return false; }
     
     access::rw(means).zeros(X.n_rows, N_gaus);
     
@@ -859,7 +859,7 @@ gmm_diag<eT>::kmeans_wrapper
     
     stream_state.restore(get_cout_stream());
     
-    if(status == false)  { arma_debug_warn_level(3, "kmeans(): clustering failed; not enough data, or too many means requested"); return false; }
+    if(status == false)  { arma_warn(3, "kmeans(): clustering failed; not enough data, or too many means requested"); return false; }
     }
   
   return true;
@@ -878,7 +878,7 @@ inline
 void
 gmm_diag<eT>::init(const gmm_diag<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   gmm_diag<eT>& t = *this;
   
@@ -899,7 +899,7 @@ inline
 void
 gmm_diag<eT>::init(const gmm_full<eT>& x)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(hefts) = x.hefts;
   access::rw(means) = x.means;
@@ -931,7 +931,7 @@ inline
 void
 gmm_diag<eT>::init(const uword in_n_dims, const uword in_n_gaus)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   access::rw(means).zeros(in_n_dims, in_n_gaus);
   
@@ -951,7 +951,7 @@ inline
 void
 gmm_diag<eT>::init_constants()
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1009,7 +1009,7 @@ inline
 umat
 gmm_diag<eT>::internal_gen_boundaries(const uword N) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   #if defined(ARMA_USE_OPENMP)
     const uword n_threads_avail = (omp_in_parallel()) ? uword(1) : uword(omp_get_max_threads());
@@ -1056,7 +1056,7 @@ inline
 eT
 gmm_diag<eT>::internal_scalar_log_p(const eT* x) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT* log_hefts_mem = log_hefts.mem;
   
@@ -1070,7 +1070,7 @@ gmm_diag<eT>::internal_scalar_log_p(const eT* x) const
       {
       const eT tmp = internal_scalar_log_p(x, g) + log_hefts_mem[g];
       
-      log_sum = log_add_exp(log_sum, tmp);
+      log_sum = priv::internal_log_add_exp(log_sum, tmp);
       }
     
     return log_sum;
@@ -1088,7 +1088,7 @@ inline
 eT
 gmm_diag<eT>::internal_scalar_log_p(const eT* x, const uword g) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const eT*     mean =     means.colptr(g);
   const eT* inv_dcov = inv_dcovs.colptr(g);
@@ -1129,9 +1129,9 @@ inline
 Row<eT>
 gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
   
   const uword N = X.n_cols;
   
@@ -1181,10 +1181,10 @@ inline
 Row<eT>
 gmm_diag<eT>::internal_vec_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_diag::log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::log_p(): incompatible dimensions" );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_diag::log_p(): specified gaussian is out of range" );
   
   const uword N = X.n_cols;
   
@@ -1234,9 +1234,9 @@ inline
 eT
 gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::sum_log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::sum_log_p(): incompatible dimensions" );
     
   const uword N = X.n_cols;
   
@@ -1290,10 +1290,10 @@ inline
 eT
 gmm_diag<eT>::internal_sum_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::sum_log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_diag::sum_log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::sum_log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_diag::sum_log_p(): specified gaussian is out of range" );
     
   const uword N = X.n_cols;
   
@@ -1347,9 +1347,9 @@ inline
 eT
 gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::avg_log_p(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::avg_log_p(): incompatible dimensions" );
     
   const uword N = X.n_cols;
   
@@ -1414,10 +1414,10 @@ inline
 eT
 gmm_diag<eT>::internal_avg_log_p(const Mat<eT>& X, const uword gaus_id) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
-  arma_debug_check( (X.n_rows != means.n_rows), "gmm_diag::avg_log_p(): incompatible dimensions"            );
-  arma_debug_check( (gaus_id  >= means.n_cols), "gmm_diag::avg_log_p(): specified gaussian is out of range" );
+  arma_conform_check( (X.n_rows != means.n_rows), "gmm_diag::avg_log_p(): incompatible dimensions"            );
+  arma_conform_check( (gaus_id  >= means.n_cols), "gmm_diag::avg_log_p(): specified gaussian is out of range" );
   
   const uword N = X.n_cols;
   
@@ -1482,13 +1482,13 @@ inline
 uword
 gmm_diag<eT>::internal_scalar_assign(const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions" );
-  arma_debug_check( (N_gaus == 0),        "gmm_diag::assign(): model has no means"      );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions" );
+  arma_conform_check( (N_gaus == 0),        "gmm_diag::assign(): model has no means"      );
   
   const eT* X_mem = X.colptr(0);
   
@@ -1525,7 +1525,7 @@ gmm_diag<eT>::internal_scalar_assign(const Mat<eT>& X, const gmm_dist_mode& dist
     }
   else
     {
-    arma_debug_check(true, "gmm_diag::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_diag::assign(): unsupported distance mode");
     }
   
   return uword(0);
@@ -1538,12 +1538,12 @@ inline
 void
 gmm_diag<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
   
-  arma_debug_check( (X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions" );
+  arma_conform_check( (X.n_rows != N_dims), "gmm_diag::assign(): incompatible dimensions" );
   
   const uword X_n_cols = (N_gaus > 0) ? X.n_cols : 0;
   
@@ -1644,7 +1644,7 @@ gmm_diag<eT>::internal_vec_assign(urowvec& out, const Mat<eT>& X, const gmm_dist
     }
   else
     {
-    arma_debug_check(true, "gmm_diag::assign(): unsupported distance mode");
+    arma_conform_check(true, "gmm_diag::assign(): unsupported distance mode");
     }
   }
 
@@ -1656,7 +1656,7 @@ inline
 void
 gmm_diag<eT>::internal_raw_hist(urowvec& hist, const Mat<eT>& X, const gmm_dist_mode& dist_mode) const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1803,7 +1803,7 @@ inline
 void
 gmm_diag<eT>::generate_initial_means(const Mat<eT>& X, const gmm_seed_mode& seed_mode)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -1897,7 +1897,7 @@ inline
 void
 gmm_diag<eT>::generate_initial_params(const Mat<eT>& X, const eT var_floor)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
@@ -2050,7 +2050,7 @@ inline
 bool
 gmm_diag<eT>::km_iterate(const Mat<eT>& X, const uword max_iter, const bool verbose, const char* signature)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(verbose)
     {
@@ -2239,7 +2239,7 @@ gmm_diag<eT>::km_iterate(const Mat<eT>& X, const uword max_iter, const bool verb
           }
         else
           {
-          // recover by using a randomly seleced sample (last resort)
+          // recover by using a randomly selected sample (last resort)
           proposed_i = as_scalar(randi<uvec>(1, distr_param(0,X_n_cols-1)));
           }
         
@@ -2277,7 +2277,7 @@ gmm_diag<eT>::km_iterate(const Mat<eT>& X, const uword max_iter, const bool verb
   
   access::rw(means) = old_means;
   
-  if(means.is_finite() == false)  { return false; }
+  if(means.internal_has_nonfinite())  { return false; }
   
   return true;
   }
@@ -2290,7 +2290,7 @@ inline
 bool
 gmm_diag<eT>::em_iterate(const Mat<eT>& X, const uword max_iter, const eT var_floor, const bool verbose)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   if(X.n_cols == 0)  { return true; }
   
@@ -2371,9 +2371,9 @@ gmm_diag<eT>::em_iterate(const Mat<eT>& X, const uword max_iter, const eT var_fl
   
   
   if(any(vectorise(dcovs) <= eT(0)))  { return false; }
-  if(means.is_finite() == false    )  { return false; }
-  if(dcovs.is_finite() == false    )  { return false; }
-  if(hefts.is_finite() == false    )  { return false; }
+  if(means.internal_has_nonfinite())  { return false; }
+  if(dcovs.internal_has_nonfinite())  { return false; }
+  if(hefts.internal_has_nonfinite())  { return false; }
   
   return true;
   }
@@ -2395,7 +2395,7 @@ gmm_diag<eT>::em_update_params
         Col<eT>&          t_progress_log_lhood
   )
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_threads = boundaries.n_cols;
   
@@ -2526,7 +2526,7 @@ gmm_diag<eT>::em_generate_acc
   )
   const
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   progress_log_lhood = eT(0);
   
@@ -2556,7 +2556,7 @@ gmm_diag<eT>::em_generate_acc
     
     for(uword g=1; g < N_gaus; ++g)
       {
-      log_lhood_sum = log_add_exp(log_lhood_sum, gaus_log_lhoods_mem[g]);
+      log_lhood_sum = priv::internal_log_add_exp(log_lhood_sum, gaus_log_lhoods_mem[g]);
       }
     
     progress_log_lhood += log_lhood_sum;
@@ -2591,7 +2591,7 @@ inline
 void
 gmm_diag<eT>::em_fix_params(const eT var_floor)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword N_dims = means.n_rows;
   const uword N_gaus = means.n_cols;
