@@ -35,9 +35,8 @@
   #endif
 #endif
 
-// NOTE:
-// "char" is not guaranteed to be the same as "signed char" 
-// https://en.wikipedia.org/wiki/C_data_types
+// NOTE: "char" can be either "signed char" or "unsigned char"
+// NOTE: https://en.wikipedia.org/wiki/C_data_types
 
 
 #if   USHRT_MAX >= 0xffff
@@ -108,12 +107,9 @@ typedef void* void_ptr;
 //
 
 
-#if   defined(ARMA_BLAS_LONG_LONG)
+#if defined(ARMA_BLAS_64BIT_INT)
   typedef long long blas_int;
   #define ARMA_MAX_BLAS_INT 0x7fffffffffffffffULL
-#elif defined(ARMA_BLAS_LONG)
-  typedef long      blas_int;
-  #define ARMA_MAX_BLAS_INT 0x7fffffffffffffffUL
 #else
   typedef int       blas_int;
   #define ARMA_MAX_BLAS_INT 0x7fffffffU
@@ -123,7 +119,7 @@ typedef void* void_ptr;
 //
 
 
-#ifdef ARMA_USE_MKL_TYPES
+#if defined(ARMA_USE_MKL_TYPES)
   // for compatibility with MKL
   typedef MKL_Complex8  blas_cxf;
   typedef MKL_Complex16 blas_cxd;
